@@ -88,8 +88,8 @@ def build(input_graph_string, timestamp):
     build_ip(anm)
 
     #TODO: make ip6 toggled by graph attribute
-    build_ip6(anm)
-    #anm.add_overlay("ip6")
+    #build_ip6(anm)
+    anm.add_overlay("ip6")
     
     igp = G_in.data.igp or "ospf" #TODO: make default template driven
 #TODO: make the global igp be set on each node - this way can also support different IGPs per router
@@ -98,6 +98,7 @@ def build(input_graph_string, timestamp):
     anm.add_overlay("ospf")
     anm.add_overlay("isis")
 
+
     G_phy = anm['phy']
     ank.copy_attr_from(G_in, G_phy, "include_csr") #TODO: find more elegant passing method from input to compiler
 
@@ -196,6 +197,9 @@ def build_bgp(anm):
             if not node.ibgp_level and node.ibgp_level != 0: 
                 node.ibgp_level = 1
 
+            if node.ibgp_level == "None": # if unicode string from yEd
+                node.ibgp_level = 1
+
             node.ibgp_level = int(node.ibgp_level) # ensure is numeric
 
             if not node.ibgp_l2_cluster or node.ibgp_l2_cluster == "None":
@@ -451,6 +455,7 @@ def build_ospf(anm):
     G_ospf.add_edges_from(G_in.edges(), retain = ['edge_id'])
 
     ank.copy_attr_from(G_in, G_ospf, "ospf_area", dst_attr = "area") #TODO: move this into graphml (and later gml) reader
+    ank.copy_edge_attr_from(G_in, G_ospf, "ospf_cost", dst_attr = "cost") #TODO: move this into graphml (and later gml) reader
 
     ank.aggregate_nodes(G_ospf, G_ospf.nodes("is_switch"), retain = "edge_id")
     ank.explode_nodes(G_ospf, G_ospf.nodes("is_switch"), retain= "edge_id")
@@ -525,7 +530,8 @@ def build_ospf(anm):
 #TODO: do we want to allocate non-symmetric OSPF costs? do we need a directed OSPF graph?
 # (note this will all change once have proper interface nodes)
     for link in G_ospf.edges():
-        link.cost = 1
+        if not link.cost:
+            link.cost = 1
 
 def ip_to_net_ent_title_ios(ip):
     """ Converts an IP address into an OSI Network Entity Title
