@@ -14,10 +14,15 @@ from collections import defaultdict
 def load_graphml(input_data):
     #TODO: allow default properties to be passed in as dicts
 
+
     try:
         graph = nx.read_graphml(input_data)
     except IOError, e:
-        if e.errno == 63:
+        acceptable_errors = set([
+            2, # no such file or directory
+            63, # input string too long for filename
+            ])
+        if e.errno in acceptable_errors:
             # try as data string rather than filename string
             try:
                 input_pseduo_fh = StringIO(input_data) # load into filehandle to networkx
